/**
 * Copyright (C) 2020-2023 DCsunset
 * See full notice in README.md in this project
 */
import path from "path";
import os from "os";
import fs from "node:fs";
export const pathConfig = {
    root: process.env.TASK_JSON_PATH || path.join(os.homedir(), ".config/task.json"),
    // relative to root
    server: "server.json",
    task: "task.json",
    workspace: "workspace.json"
};
export function emptyRootGuard() {
    if (!fs.existsSync(pathConfig.root)) {
        fs.mkdirSync(pathConfig.root, { recursive: true });
    }
}
function deserializeData(data) {
    return data
        .trim() // Trim white spaces to avoid empty lines
        .split("\n")
        .map(line => JSON.parse(line));
}
;
function serializeData(data) {
    // Make sure a new line is at the end
    return data
        .map(item => JSON.stringify(item) + "\n")
        .join("");
}
;
export async function readData(type) {
    const dataPath = path.join(pathConfig.root, pathConfig[type]);
    try {
        return deserializeData(fs.readFileSync(dataPath, "utf-8"));
    }
    catch (err) {
        return [];
    }
}
/// null means deleting the file
export function writeData(type, data) {
    emptyRootGuard();
    const dataPath = path.join(pathConfig.root, pathConfig[type]);
    // Backup task.json
    if (type === "task" && fs.existsSync(dataPath))
        fs.renameSync(dataPath, dataPath + ".bak");
    if (data === null) {
        if (fs.existsSync(dataPath))
            fs.unlinkSync(dataPath);
    }
    else {
        fs.writeFileSync(dataPath, serializeData(data), { encoding: "utf8" });
    }
}
/// Assume that there is a new line at the end of file
export function appendData(type, data) {
    emptyRootGuard();
    const dataPath = path.join(pathConfig.root, pathConfig[type]);
    // Backup task.json
    if (type === "task" && fs.existsSync(dataPath))
        fs.copyFileSync(dataPath, dataPath + ".bak");
    fs.appendFileSync(dataPath, serializeData(data), { encoding: "utf8" });
}
//# sourceMappingURL=config.js.map